@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object 'envresmulti';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-15'; # DATE
+our $DATE = '2022-10-10'; # DATE
 our $DIST = 'App-GoogleSearchUtils'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our %SPEC;
 
@@ -439,7 +439,7 @@ App::GoogleSearchUtils - CLI utilites related to google searching
 
 =head1 VERSION
 
-This document describes version 0.013 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-09-15.
+This document describes version 0.014 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-10-10.
 
 =head1 SYNOPSIS
 
@@ -578,6 +578,11 @@ Source repository is at L<https://github.com/perlancar/perl-App-GoogleSearchUtil
 
 =head1 SEE ALSO
 
+L<App::WebSearchUtils>, L<App::DDGSearchUtils>, L<App::BraveSearchUtils>,
+L<App::BingSearchUtils> - I'm sick of getting CAPTCHA's with Google (how many
+times in a few minutes do I have to prove that I'm human?), so lately been
+switching to other search engines when I have to do many searches.
+
 
 L<App::FirefoxMultiAccountContainersUtils>.
 
